---
title: bsu
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview

This defined type allows you add or remove BSU patches to a WebLogic system. Here is an example on how you could use this:

```puppet
orawls::bsu {'BYJ1':
  ensure                  => "present",
  middleware_home_dir     => "/opt/oracle/middleware11gR1",
  weblogic_home_dir       => "/opt/oracle/middleware11gR1/wlserver",
  jdk_home_dir            => "/usr/java/jdk1.7.0_45",
  patch_id                => "BYJ1",
  patch_file              => "p17071663_1036_Generic.zip",
  os_user                 => "oracle",
  os_group                => "dba",
  download_dir            => "/data/install",
  source                  => "/vagrant",
}
```




## Attributes



Attribute Name                              | Short Description                                                                                 |
------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[download_dir](#bsu_download_dir)           | The directory where the Puppet software puts all downloaded files.                                |
[ensure](#bsu_ensure)                       | State to obtain.                                                                                  |
[jdk_home_dir](#bsu_jdk_home_dir)           | The homdirectory for the Java evelopment Kit.                                                     |
[log_output](#bsu_log_output)               | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#bsu_logoutput)                 | log the outputs of Puppet exec or not.                                                            |
[os_group](#bsu_os_group)                   | The os group used to install and run WebLogic.                                                    |
[os_user](#bsu_os_user)                     | The os user used to install and run WebLogic.                                                     |
[patch_file](#bsu_patch_file)               | File containing the BSU patch.                                                                    |
[patch_id](#bsu_patch_id)                   | Patch id to apply.                                                                                |
[remote_file](#bsu_remote_file)             | This parameter is not being used anymore and will be removed in a future release.                 |
[source](#bsu_source)                       | Source for the operation.                                                                         |
[version](#bsu_version)                     | The version that is installed in the used Oracle home.                                            |
[weblogic_home_dir](#bsu_weblogic_home_dir) | Directory to use as WebLogic home.                                                                |




### ensure<a name='bsu_ensure'>

State to obtain.

The ensure attribute can be one of two values:

- present
- absent

When you specify `present`, Puppet will make sure the resource is available with all specified options and properties.

When the resource is already available(installed), and all attributes are as the are specified, Puppet will do nothing.

When you specify `absent`, Puppet will remove the resource if it is available. If it is not installed, Puppet will do nothing.

Type: `Enum[
    present,
    absent
  ]`

Default:`'present'`

[Back to overview of bsu](#attributes)

### version<a name='bsu_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Variant[
    Integer[1036,1036],
    Integer[1111,1111],
    Integer[1211,1211]
  ]`

Default:`lookup({name => 'wls_version', default_value => 1036})`

[Back to overview of bsu](#attributes)

### weblogic_home_dir<a name='bsu_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir', default_value => undef})`

[Back to overview of bsu](#attributes)

### jdk_home_dir<a name='bsu_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir', default_value => undef})`

[Back to overview of bsu](#attributes)

### patch_id<a name='bsu_patch_id'>

Patch id to apply.

Type: `String[1]`

Default:`undef`

[Back to overview of bsu](#attributes)

### patch_file<a name='bsu_patch_file'>

File containing the BSU patch.

Type: `String[1]`

Default:`undef`

[Back to overview of bsu](#attributes)

### os_user<a name='bsu_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user', default_value => undef})`

[Back to overview of bsu](#attributes)

### os_group<a name='bsu_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group', default_value => undef})`

[Back to overview of bsu](#attributes)

### download_dir<a name='bsu_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir', default_value => undef})`

[Back to overview of bsu](#attributes)

### source<a name='bsu_source'>

Source for the operation.

Type: `String[1]`

Default:`lookup({name => 'wls_source', default_value => undef})`

[Back to overview of bsu](#attributes)

### logoutput<a name='bsu_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of bsu](#attributes)

### log_output<a name='bsu_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum['on_failure']
    ]
  ]`

Default:`undef`

[Back to overview of bsu](#attributes)

### remote_file<a name='bsu_remote_file'>

**DEPRECATED**
This parameter is not being used anymore and will be removed in a future release.

`true`.

Type: `Optional[Boolean]`

Default:`undef`

[Back to overview of bsu](#attributes)
