---
title: copydomain
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview

 This defined type allows you copy a domain to an other WebLogic node. It is used in conjunction with ora_install::packdomain to build WebLogic clusters. Here is an example on how you could use this:

```puppet
ora_install::copydomain{"Wls12c":
  version                => 1212,
  weblogic_home_dir      => "/opt/oracle/middleware12c/wlserver",
  middleware_home_dir    => "/opt/oracle/middleware12c",
  jdk_home_dir           => "/usr/java/jdk1.7.0_45",
  wls_domains_dir        => "/opt/oracle/domains",
  wls_apps_dir           => "/opt/oracle/applications",
  domain_name            => "Wls12c",
  os_user                => "oracle",
  os_group               => "dba",
  download_dir           => "/data/install",
  log_dir                => "/var/log/weblogic",
  log_output             => true,
  use_ssh                => false,
  domain_pack_dir        => /mnt/fmw_share,
  adminserver_address    => "10.10.10.10",
  adminserver_port       => 7001,
  weblogic_user          => "weblogic",
  weblogic_password      => "weblogic1",
  setinternalappdeploymentondemandenable => false,
  setconfigbackupenabled                 => true,
  setarchiveconfigurationcount           => 10,
  setconfigurationaudittype              => 'logaudit',
}
```




## Attributes



Attribute Name                                                     | Short Description                                                                                 |
------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------- |
[adminserver_address](#copydomain_adminserver_address)             | The address of the admin server.                                                                  |
[adminserver_port](#copydomain_adminserver_port)                   | The IP port the admin server is listening on.                                                     |
[copy_script](#copydomain_copy_script)                             | The user provided copy script to use for copying the packed domain.                               |
[custom_trust](#copydomain_custom_trust)                           | Determine if you want to use a custom trust or not.                                               |
[domain_name](#copydomain_domain_name)                             | The domain name.                                                                                  |
[domain_pack_dir](#copydomain_domain_pack_dir)                     | Directory where to put the packed directory.                                                      |
[download_dir](#copydomain_download_dir)                           | The directory where the Puppet software puts all downloaded files.                                |
[extra_arguments](#copydomain_extra_arguments)                     | Extra java arguments to use.                                                                      |
[jdk_home_dir](#copydomain_jdk_home_dir)                           | The homdirectory for the Java evelopment Kit.                                                     |
[jsse_enabled](#copydomain_jsse_enabled)                           | Determine if you want to enable JSSE security.                                                    |
[log_dir](#copydomain_log_dir)                                     | Directory to use for logging.                                                                     |
[log_output](#copydomain_log_output)                               | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#copydomain_logoutput)                                 | log the outputs of Puppet exec or not.                                                            |
[middleware_home_dir](#copydomain_middleware_home_dir)             | Middleware home directory.                                                                        |
[os_group](#copydomain_os_group)                                   | The os group used to install and run WebLogic.                                                    |
[os_user](#copydomain_os_user)                                     | The os user used to install and run WebLogic.                                                     |
[puppet_os_user](#copydomain_puppet_os_user)                       | The Puppet OS user to use.                                                                        |
[server_start_mode](#copydomain_server_start_mode)                 | Startmode to use.                                                                                 |
[trust_keystore_file](#copydomain_trust_keystore_file)             | File specificiation of the trust keystore.                                                        |
[trust_keystore_passphrase](#copydomain_trust_keystore_passphrase) | Passphrase to use for the trust keystore.                                                         |
[use_ssh](#copydomain_use_ssh)                                     | Boolean value specifying if you want to use ssh to copy the packed file.                          |
[use_t3s](#copydomain_use_t3s)                                     | This parameter is not used (yet).                                                                 |
[user_config_file](#copydomain_user_config_file)                   | This parameter is not used (yet).                                                                 |
[user_key_file](#copydomain_user_key_file)                         | This parameter is not used (yet).                                                                 |
[version](#copydomain_version)                                     | The version that is installed in the used Oracle home.                                            |
[weblogic_home_dir](#copydomain_weblogic_home_dir)                 | Directory to use as WebLogic home.                                                                |
[weblogic_password](#copydomain_weblogic_password)                 | The password of the base WebLogic user name.                                                      |
[weblogic_user](#copydomain_weblogic_user)                         | The base WebLogic username to configure.                                                          |
[wls_apps_dir](#copydomain_wls_apps_dir)                           | The root directory where all aplication directories reside in.                                    |
[wls_domains_dir](#copydomain_wls_domains_dir)                     | The root directory where all domain directories reside in.                                        |
[wls_domains_file](#copydomain_wls_domains_file)                   | file containing the current domains available on the system.                                      |




### version<a name='copydomain_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Wls_install::Versions`

Default:`lookup({name => 'wls_version', default_value => 1111})`

[Back to overview of copydomain](#attributes)

### middleware_home_dir<a name='copydomain_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_middleware_home_dir'})`

[Back to overview of copydomain](#attributes)

### weblogic_home_dir<a name='copydomain_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir'})`

[Back to overview of copydomain](#attributes)

### jdk_home_dir<a name='copydomain_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir'})`

[Back to overview of copydomain](#attributes)

### wls_domains_dir<a name='copydomain_wls_domains_dir'>

The root directory where all domain directories reside in.

Type: `Optional[Stdlib::Absolutepath]`

Default:`lookup({name => 'wls_domains_dir', default_value => undef})`

[Back to overview of copydomain](#attributes)

### wls_apps_dir<a name='copydomain_wls_apps_dir'>

The root directory where all aplication directories reside in.

Type: `Optional[Stdlib::Absolutepath]`

Default:`lookup({name => 'wls_apps_dir', default_value => undef})`

[Back to overview of copydomain](#attributes)

### use_ssh<a name='copydomain_use_ssh'>

Boolean value specifying if you want to use ssh to copy the packed file. You can only use this
when the ssh keys are already provided.
Type: `Boolean`

Default:`true`

[Back to overview of copydomain](#attributes)

### domain_pack_dir<a name='copydomain_domain_pack_dir'>

Directory where to put the packed directory.

Type: `Optional[Stdlib::Absolutepath]`

Default:`undef`

[Back to overview of copydomain](#attributes)

### domain_name<a name='copydomain_domain_name'>

The domain name.

Type: `String[1]`

Default:`lookup({name => 'domain_name'})`

[Back to overview of copydomain](#attributes)

### adminserver_address<a name='copydomain_adminserver_address'>

The address of the admin server. May be a DNS name or a physical IP address.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver_address'})`

[Back to overview of copydomain](#attributes)

### adminserver_port<a name='copydomain_adminserver_port'>

The IP port the admin server is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_adminserver_port', default_value => 7001})`

[Back to overview of copydomain](#attributes)

### use_t3s<a name='copydomain_use_t3s'>

This parameter is not used (yet).

Type: `Boolean`

Default:`false`

[Back to overview of copydomain](#attributes)

### user_config_file<a name='copydomain_user_config_file'>

This parameter is not used (yet).

Type: `Optional[String[1]]`

Default:`lookup({name => 'domain_user_config_file', default_value => undef})`

[Back to overview of copydomain](#attributes)

### user_key_file<a name='copydomain_user_key_file'>

This parameter is not used (yet).

Type: `Optional[String[1]]`

Default:`lookup({name => 'domain_user_key_file', default_value => undef})`

[Back to overview of copydomain](#attributes)

### weblogic_user<a name='copydomain_weblogic_user'>

The base WebLogic username to configure.

Type: `String[1]`

Default:`lookup({name => 'wls_weblogic_user', default_value => 'weblogic'})`

[Back to overview of copydomain](#attributes)

### weblogic_password<a name='copydomain_weblogic_password'>

The password of the base WebLogic user name.

Type: `String[1]`

Default:`lookup({name => 'domain_wls_password', default_value => undef})`

[Back to overview of copydomain](#attributes)

### os_user<a name='copydomain_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of copydomain](#attributes)

### os_group<a name='copydomain_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of copydomain](#attributes)

### download_dir<a name='copydomain_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of copydomain](#attributes)

### log_dir<a name='copydomain_log_dir'>

Directory to use for logging.

Type: `Optional[Stdlib::Absolutepath]`

Default:`lookup({name => 'wls_log_dir', default_value => undef})`

[Back to overview of copydomain](#attributes)

### server_start_mode<a name='copydomain_server_start_mode'>

Startmode to use. This parameter id directly passed to the unpack and start of the domain.

Valid values are:

- dev
- prod
Type: `Enum['dev','prod']`

Default:`'dev'`

[Back to overview of copydomain](#attributes)

### wls_domains_file<a name='copydomain_wls_domains_file'>

file containing the current domains available on the system.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of copydomain](#attributes)

### copy_script<a name='copydomain_copy_script'>

The user provided copy script to use for copying the packed domain.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of copydomain](#attributes)

### puppet_os_user<a name='copydomain_puppet_os_user'>

The Puppet OS user to use.

Type: `String[1]`

Default:`'root'`

[Back to overview of copydomain](#attributes)

### jsse_enabled<a name='copydomain_jsse_enabled'>

Determine if you want to enable JSSE security.

Type: `Boolean`

Default:`lookup({name => 'wls_jsse_enabled', default_value => false})`

[Back to overview of copydomain](#attributes)

### custom_trust<a name='copydomain_custom_trust'>

Determine if you want to use a custom trust or not.

Type: `Boolean`

Default:`lookup({name => 'wls_custom_trust', default_value => false})`

[Back to overview of copydomain](#attributes)

### trust_keystore_file<a name='copydomain_trust_keystore_file'>

File specificiation of the trust keystore.


Type: `Optional[String[1]]`

Default:`lookup({name => 'wls_trust_keystore_file', default_value => undef})`

[Back to overview of copydomain](#attributes)

### trust_keystore_passphrase<a name='copydomain_trust_keystore_passphrase'>

Passphrase to use for the trust keystore.

Type: `Optional[String[1]]`

Default:`lookup({name => 'wls_trust_keystore_passphrase', default_value => undef})`

[Back to overview of copydomain](#attributes)

### extra_arguments<a name='copydomain_extra_arguments'>

Extra java arguments to use.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of copydomain](#attributes)

### log_output<a name='copydomain_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum['on_failure']
    ]
  ]`

Default:`undef`

[Back to overview of copydomain](#attributes)

### logoutput<a name='copydomain_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of copydomain](#attributes)
