# Override the default Oracle operating system user
Default this `wls_install` module uses oracle as weblogic install user. You can override this by setting the following fact `override_weblogic_user`. For example:

```
$ export override_weblogic_user=wls
``` 
or 

```
set FACTER_override_weblogic_user=wls
```

# Override the default WebLogic domain folder
Set the following hiera parameters for software.pp

```yaml
  wls_domains_dir:   '/opt/oracle/wlsdomains/domains'
  wls_apps_dir:      '/opt/oracle/wlsdomains/applications'
```

Set the following `wls_domains_dir` and `wls_apps_dir` parameters in
- `wls_install::software`
- `wls_install::domain`
- `wls_install::control`
- `wls_install::packdomain`
- `wls_install::copydomain`
- `wls_install::fmwcluster`
- `wls_install::fmwclusterjrf`

or hiera parameters of `wls_install::software`

```yaml
  wls_install::software::wls_domains_dir:      *wls_domains_dir
  wls_install::software::wls_apps_dir:         *wls_apps_dir
```

# Java Secure Socket Extension support

Requires the JDK 7 or 8 JCE extension

```puppet
jdk7::install7{ 'jdk1.7.0_51':
  version                   => "7u51" ,
  fullVersion               => "jdk1.7.0_51",
  alternativesPriority      => 18000,
  x64                       => true,
  downloadDir               => "/data/install",
  urandomJavaFix            => true,
  rsakeySizeFix             => true,                          <!--
  cryptographyExtensionFile => "UnlimitedJCEPolicyJDK7.zip",  <!---
  sourcePath                => "/software",
}
```

To enable this in wls_install you can set the `jsse_enabled` parameter on the following manifests
- `wls_install::nodemanager`
- `wls_install::domain`
- `wls_install::control`

or set the following hiera parameter

```yaml
  wls_jsse_enabled:         true
```

# Enterprise security with Custom Identity and Trust store
In combination with JDK7 JCE policy, ORAUTILS and WebLogic JSSE you can use your own certificates just generates all the certificates and set the following hiera variables.

```yaml
# custom trust
orautils::customTrust:             true
orautils::trustKeystoreFile:       '/vagrant/truststore.jks'
orautils::trustKeystorePassphrase: 'welcome'

# used by nodemanager, control and domain creation
wls_custom_trust:                  &wls_custom_trust              true
wls_trust_keystore_file:           &wls_trust_keystore_file       '/vagrant/truststore.jks'
wls_trust_keystore_passphrase:     &wls_trust_keystore_passphrase 'welcome'

wls_setting_instances:
  'default':
    user:                      oracle
    weblogic_home_dir:         '/opt/oracle/middleware11g/wlserver_10.3'
    connect_url:               't3s://10.10.10.10:7002'
    weblogic_user:             'weblogic'
    weblogic_password:         'Welcome01'
    custom_trust:              *wls_custom_trust
    trust_keystore_file:       *wls_trust_keystore_file
    trust_keystore_passphrase: *wls_trust_keystore_passphrase

# create a standard domain with custom identity for the adminserver
domain_instances:
  'Wls1036':
    domain_template:                       "standard"
    development_mode:                      false
    log_output:                            *logoutput
    custom_identity:                       true
    custom_identity_keystore_filename:     '/vagrant/identity_admin.jks'
    custom_identity_keystore_passphrase:   'welcome'
    custom_identity_alias:                 'admin'
    custom_identity_privatekey_passphrase: 'welcome'

nodemanager_instances:
  'nodemanager':
    log_output:                            *logoutput
    custom_identity:                       true
    custom_identity_keystore_filename:     '/vagrant/identity_admin.jks'
    custom_identity_keystore_passphrase:   'welcome'
    custom_identity_alias:                 'admin'
    custom_identity_privatekey_passphrase: 'welcome'
    nodemanager_address:                   *domain_adminserver_address

server_instances:
  'wlsServer1':
    ensure:                                'present'
    arguments:                             '-XX:PermSize=256m -XX:MaxPermSize=256m -Xms752m -Xmx752m -Dweblogic.Stdout=/var/log/weblogic/wlsServer1.out -Dweblogic.Stderr=/var/log/weblogic/wlsServer1_err.out'
    listenaddress:                         '10.10.10.100'
    listenport:                            '8001'
    logfilename:                           '/var/log/weblogic/wlsServer1.log'
    machine:                               'Node1'
    sslenabled:                            '1'
    ssllistenport:                         '8201'
    sslhostnameverificationignored:        '1'
    jsseenabled:                           '1'
    custom_identity:                       '1'
    custom_identity_keystore_filename:     '/vagrant/identity_node1.jks'
    custom_identity_keystore_passphrase:   'welcome'
    custom_identity_alias:                 'node1'
    custom_identity_privatekey_passphrase: 'welcome'
    trust_keystore_file:                   *wls_trust_keystore_file
    trust_keystore_passphrase:             *wls_trust_keystore_passphrase
```

# Linux low on entropy or urandom fix
Linux low on entropy can cause certain operations to be very slow. Encryption operations need entropy to ensure randomness. Entropy is generated by the OS when you use the keyboard, the mouse or the disk. If an encryption operation is missing entropy it will wait until enough is generated.

three options
-  use rngd service (include `wls_install::urandomfix` class)
-  set java.security in JDK ( jre/lib/security in my jdk7 module )
-  set `-Djava.security.egd=file:/dev/./urandom` param

# Oracle binaries files and alternate download location
Some manifests like `wls_install:weblogic`, `wls_install::bsu`, `wls_install::opatch`, `wls_install::fmw` support an alternative mountpoint for the big oracle setup/install files. When not provided it uses the files folder located in the `wls_install` puppet module
else you can use `$source` =>
- "/mnt"
- "/vagrant"
- "puppet:///modules/wls_install/" (default)
- "puppet:///middleware/"

when the files are also accessible locally then you can also set $remote_file => false this will not move the files to the download folder, just extract or install

# `wls_install` api

## software
`wls_install::software` installs WebLogic 10.3.[0-6], 12.1.1, 12.1.2 & 12.1.3

```puppet
class{'wls_install::software':
  version              => 1212,                       # 1036|1211|1212|1213
  filename             => 'wls_121200.jar',           # wls1036_generic.jar|wls1211_generic.jar|wls_121200.jar
  jdk_home_dir         => '/usr/java/jdk1.7.0_45',
  oracle_base_home_dir => "/opt/oracle",
  middleware_home_dir  => "/opt/oracle/middleware12c",
  weblogic_home_dir    => "/opt/oracle/middleware12c/wlserver",
  os_user              => "oracle",
  os_group             => "dba",
  download_dir         => "/data/install",
  source               => "/vagrant",                 # puppet:///modules/wls_install/ | /mnt |
  log_output           => true,
}
```

12.1.3 infra

```puppet
class{'wls_install::software':
  version              => 1213,
  filename             => 'fmw_12.1.3.0.0_infrastructure.jar',
  fmw_infra            => true,
  jdk_home_dir         => '/usr/java/jdk1.7.0_55',
  oracle_base_home_dir => "/opt/oracle",
  middleware_home_dir  => "/opt/oracle/middleware12c",
  weblogic_home_dir    => "/opt/oracle/middleware12c/wlserver",
  os_user              => "oracle",
  os_group             => "dba",
  download_dir         => "/data/install",
  source               => "puppet:///middleware",
  log_output           => true,
}
```

or with a bin file located on a share

```puppet
class{'wls_install::software':
  version              => 1036,
  filename             => "oepe-wls-indigo-installer-11.1.1.8.0.201110211138-10.3.6-linux32.bin",
  oracle_base_home_dir => "/opt/weblogic",
  middleware_home_dir  => "/opt/weblogic/Middleware",
  weblogic_home_dir    => "/opt/weblogic/Middleware/wlserver_10.3",
  fmw_infra            => false,
  jdk_home_dir         => "/usr/java/latest",
  os_user              => "weblogic",
  os_group             => "bea",
  download_dir         => "/data/tmp",
  source               => "/misc/tact/products/oracle/11g/fmw/wls/11.1.1.8",
  remote_file          => false,
  log_output           => true,
  temp_directory       => "/data/tmp",
 }
```

## opatch
`wls_install::opatch` apply an OPatch on a Middleware home or a Oracle product home

```puppet
wls_install::opatch {'16175470':
  ensure                  => "present",
  oracle_product_home_dir => "/opt/oracle/middleware12c",
  jdk_home_dir            => "/usr/java/jdk1.7.0_45",
  patch_id                => "16175470",
  patch_file              => "p16175470_121200_Generic.zip",
  os_user                 => "oracle",
  os_group                => "dba",
  download_dir            => "/data/install",
  source                  => "/vagrant",
  log_output              => false,
}
```

or when you set the defaults hiera variables

```puppet
wls_install::opatch {'16175470':
  ensure                  => "present",
  oracle_product_home_dir => "/opt/oracle/middleware12c",
  patch_id                => "16175470",
  patch_file              => "p16175470_121200_Generic.zip",
}
```

## bsu
`wls_install::bsu` apply or remove a WebLogic BSU Patch ( ensure = present or absent )

```puppet
wls_install::bsu {'BYJ1':
  ensure                  => "present",
  middleware_home_dir     => "/opt/oracle/middleware11gR1",
  weblogic_home_dir       => "/opt/oracle/middleware11gR1/wlserver",
  jdk_home_dir            => "/usr/java/jdk1.7.0_45",
  patch_id                => "BYJ1",
  patch_file              => "p17071663_1036_Generic.zip",
  os_user                 => "oracle",
  os_group                => "dba",
  download_dir            => "/data/install",
  source                  => "/vagrant",
  log_output              => false,
}
```

or when you set the defaults hiera variables

```puppet
wls_install::bsu {'BYJ1':
  ensure                  => "present",
  patch_id                => "BYJ1",
  patch_file              => "p17071663_1036_Generic.zip",
  log_output              => false,
}
```

## fmw
`wls_install::fmw`  installs FMW software (add-on) to a middleware home like OSB,SOA Suite, WebTier (HTTP Server), Oracle Identity Management, Web Center + Content

```puppet
# fmw_product = adf|soa|osb|wcc|wc|oim|web|webgate|b2b|mft
wls_install::fmw{"osbPS6":
  middleware_home_dir     => "/opt/oracle/middleware11gR1",
  weblogic_home_dir       => "/opt/oracle/middleware11gR1/wlserver",
  jdk_home_dir            => "/usr/java/jdk1.7.0_45",
  oracle_base_home_dir    => "/opt/oracle",
  fmw_product             => "osb",  # adf|soa|osb|oim|wc|wcc|web
  fmw_file1               => "ofm_osb_generic_11.1.1.7.0_disk1_1of1.zip",
  os_user                 => "oracle",
  os_group                => "dba",
  download_dir            => "/data/install",
  source                  => "/vagrant",
  log_output              => false,
}
```

or when you set the defaults hiera variables

```puppet
wls_install::fmw{"osbPS6":
  fmw_product             => "osb"  # adf|soa|osb|oim|wc|wcc|web|webgate
  fmw_file1               => "ofm_osb_generic_11.1.1.7.0_disk1_1of1.zip",
  log_output              => false,
}

wls_install::fmw{"osb12.1.3":
  version                 => 1213
  fmw_product             => "osb"
  fmw_file1               => "fmw_12.1.3.0.0_osb_Disk1_1of1.zip",
  log_output              => false,
}
```

## domain
`wls_install::domain` creates WebLogic domain like a standard | OSB or SOA Suite | ADF | WebCenter | OIM or OAM or OUD, optional override the default server arguments in the domain.py template with java_arguments parameter.

```puppet
wls_install::domain { 'wlsDomain12c':
  version                     => 1212,  # 1036|1111|1211|1212|1213
  weblogic_home_dir           => "/opt/oracle/middleware12c/wlserver",
  middleware_home_dir         => "/opt/oracle/middleware12c",
  jdk_home_dir                => "/usr/java/jdk1.7.0_45",
  domain_template             => "standard",  #standard|adf|osb|osb_soa|osb_soa_bpm|soa|soa_bpm
  domain_name                 => "Wls12c",
  development_mode            => false,
  adminserver_name            => "AdminServer",
  adminserver_address         => "localhost",
  adminserver_port            => 7001,
  nodemanager_secure_listener => true,
  nodemanager_port            => 5556,
  java_arguments              => { "ADM" => "...", "OSB" => "...", "SOA" => "...", "BAM" => "..."},
  weblogic_user               => "weblogic",
  weblogic_password           => "weblogic1",
  os_user                     => "oracle",
  os_group                    => "dba",
  log_dir                     => "/data/logs",
  download_dir                => "/data/install",
  log_output                  => true,
}
```

or when you set the defaults hiera variables

```puppet
wls_install::domain { 'wlsDomain12c':
  domain_template            => "standard",
  domain_name                => "Wls12c",
  development_mode           => false,
  adminserver_name           => "AdminServer",
  adminserver_address        => "localhost",
  adminserver_port           => 7001,
  nodemanager_port           => 5556,
  weblogic_password          => "weblogic1",
  log_output                 => true,
}
```

## packdomain
`wls_install::packdomain` pack a WebLogic Domain and add this to the download folder

```puppet
    wls_install::packdomain{"Wls12c":
      weblogic_home_dir      => "/opt/oracle/middleware12c/wlserver",
      middleware_home_dir    => "/opt/oracle/middleware12c",
      jdk_home_dir           => "/usr/java/jdk1.7.0_45",
      wls_domains_dir        => "/opt/oracle/domains",
      domain_name            => "Wls12c",
      os_user                => "oracle",
      os_group               => "dba",
      download_dir           => "/data/install",
    }

```

## copydomain
`wls_install::copydomain` copies a WebLogic domain with SSH or from a share, unpack and enroll to a nodemanager. When using ssh (use_ssh = true) you need to setup ssh so you won't need to provide a password.

```puppet
wls_install::copydomain{"Wls12c":
  version                                => 1212,
  weblogic_home_dir                      => "/opt/oracle/middleware12c/wlserver",
  middleware_home_dir                    => "/opt/oracle/middleware12c",
  jdk_home_dir                           => "/usr/java/jdk1.7.0_45",
  wls_domains_dir                        => "/opt/oracle/domains",
  wls_apps_dir                           => "/opt/oracle/applications",
  domain_name                            => "Wls12c",
  os_user                                => "oracle",
  os_group                               => "dba",
  download_dir                           => "/data/install",
  log_dir                                => "/var/log/weblogic",
  log_output                             => true,
  use_ssh                                => false,
  domain_pack_dir                        => /mnt/fmw_share,
  adminserver_address                    => "10.10.10.10",
  adminserver_port                       => 7001,
  weblogic_user                          => "weblogic",
  weblogic_password                      => "weblogic1",
  setinternalappdeploymentondemandenable => false,
  setconfigbackupenabled                 => true,
  setarchiveconfigurationcount           => 10,
  setconfigurationaudittype              => 'logaudit',
}
```

## nodemanager
`wls_install::nodemanager` start the nodemanager of a WebLogic Domain or Middleware Home

```puppet
wls_install::nodemanager{'nodemanager12c':
  version                     => 1212, # 1036|1111|1211|1212
  weblogic_home_dir           => "/opt/oracle/middleware12c/wlserver",
  jdk_home_dir                => "/usr/java/jdk1.7.0_45",
  nodemanager_port            => 5556,
  nodemanager_secure_listener => true,
  domain_name                 => "Wls12c",
  os_user                     => "oracle",
  os_group                    => "dba",
  log_dir                     => "/data/logs",
  download_dir                => "/data/install",
  log_output                  => true,
  sleep                       => 20,
}
```

## control
`wls_install::control` start or stops the AdminServer,Managed Server or a Cluster of a WebLogic Domain, this will call the `wls_managedserver` and `wls_adminserver` types.

```puppet
wls_install::control{'startWLSAdminServer12c':
  domain_name                 => "Wls12c",
  server_type                 => 'admin',  # admin|managed
  target                      => 'Server', # Server|Cluster
  server                      => 'AdminServer',
  action                      => 'start',
  weblogic_home_dir           => "/opt/oracle/middleware12c/wlserver",
  jdk_home_dir                => "/usr/java/jdk1.7.0_45",
  weblogic_user               => "weblogic",
  weblogic_password           => "weblogic1",
  adminserver_address         => 'localhost',
  adminserver_port            => 7001,
  nodemanager_port            => 5556,
  nodemanager_secure_listener => true,
  os_user                     => "oracle",
  os_group                    => "dba",
  download_dir                => "/data/install",
  log_output                  => true,
}
```

or when you set the defaults hiera variables:

```puppet
wls_install::control{'startWLSAdminServer12c':
  domain_name                => "Wls12c",
  server_type                => 'admin',  # admin|managed
  target                     => 'Server', # Server|Cluster
  server                     => 'AdminServer',
  action                     => 'start',
  weblogic_password          => "weblogic1",
  adminserver_address        => 'localhost',
  adminserver_port           => 7001,
  nodemanager_port           => 5556,
  log_output                 => true,
 }
```

## urandomfix
`wls_install::urandomfix` Linux low on entropy or urandom fix can cause certain operations to be very slow. Encryption operations need entropy to ensure randomness. Entropy is generated by the OS when you use the keyboard, the mouse or the disk. If an encryption operation is missing entropy it will wait until enough is generated. There are three options:
-  use rngd service (use this wls::urandomfix class)
-  set java.security in JDK ( jre/lib/security in my jdk7 module )
-  set -Djava.security.egd=file:/dev/./urandom param

## storeuserconfig
`wls_install::storeuserconfig` Creates WLST user config for WLST , this way you don't need to know the weblogic password.
when you set the defaults hiera variables

```puppet
wls_install::storeuserconfig{'Wls12c':
  domain_name                => "Wls12c",
  adminserver_address        => "localhost",
  adminserver_port           => 7001,
  weblogic_password          => "weblogic1",
  user_config_dir            => '/home/oracle',
  log_output                 => false,
}
```

## Dynamictargetting
Sometimes you do not know how many managed services you will have,
due to application scaling or other use cases. Since you do specify resources
like clusters and datasources in a more 'static' way, there should be a way to
qualify a managed server as a target for such resources.

We use the notes field in WebLogic Server to accomplish this. Currently implemented
for the following resource types:
- `wls_cluster`
- `wls_datasouce`
- `wls_mail_session`

The way you use this, is by entering the resource name in the server_parameter
field on the wls_server type, and put the servers field to 'inherited' on the
resource to be targeted.

Example:

```puppet

wls_server { 'wlsServer1':
  ensure                            => 'present',
  arguments                         => '-XX:PermSize=256m -XX:MaxPermSize=256m -Xms752m -Xmx752m -Dweblogic.Stdout=/var/log/weblogic/wlsServer1.out -Dweblogic.Stderr=/var/log/weblogic/wlsServer1_err.out',
  jsseenabled                       => '0',
  listenaddress                     => '10.10.10.100',
  listenport                        => '8001',
  listenportenabled                 => '1',
  machine                           => 'Node1',
  sslenabled                        => '0',
  tunnelingenabled                  => '0',
  max_message_size                  => '10000000',
  server_parameter                  => 'WebCluster, hrDs',
}

wls_cluster { 'WebCluster':
  ensure           => 'present',
  messagingmode    => 'unicast',
  migrationbasis   => 'consensus',
  servers          => ['inherited'],
  multicastaddress => '239.192.0.0',
  multicastport    => '7001',
}

wls_datasource { 'hrDS':
  ensure                           => 'present',
  connectioncreationretryfrequency => '0',
  drivername                       => 'oracle.jdbc.xa.client.OracleXADataSource',
  extraproperties                  => ['SendStreamAsBlob=true', 'oracle.net.CONNECT_TIMEOUT=10001'],
  fanenabled                       => '0',
  globaltransactionsprotocol       => 'TwoPhaseCommit',
  initialcapacity                  => '2',
  initsql                          => 'None',
  jndinames                        => ['jdbc/hrDS', 'jdbc/hrDS2'],
  maxcapacity                      => '15',
  mincapacity                      => '1',
  rowprefetchenabled               => '0',
  rowprefetchsize                  => '48',
  secondstotrustidlepoolconnection => '10',
  statementcachesize               => '10',
  target                           => ['inherited'],
  targettype                       => ['inherited'],
  testconnectionsonreserve         => '0',
  testfrequency                    => '120',
  testtablename                    => 'SQL SELECT 1 FROM DUAL',
  url                              => 'jdbc:oracle:thin:@dbagent2.alfa.local:1521/test.oracle.com',
  user                             => 'hr',
  usexa                            => '0',
}
```

In the case of the wls_datasource type, the jdbc connection will be targetted on
the cluster if the managed server is in a cluster.

## fmwlogdir
`wls_install::fmwlogdir` Change a log folder location of a FMW server
when you set the defaults hiera variables

```puppet
wls_install::fmwlogdir{'AdminServer':
  middleware_home_dir    => "/opt/oracle/middleware11gR1",
  weblogic_user          => "weblogic",
  weblogic_password      => "weblogic1",
  os_user                => "oracle",
  os_group               => "dba",
  download_dir           => "/data/install"
  log_dir                => "/var/log/weblogic"
  adminserver_address    => "localhost",
  adminserver_port       => 7001,
  server                 => "AdminServer",
  log_output             => false,
}
```

## fmwcluster
`wls_install::utils::fmwcluster` convert existing cluster to a OSB or SOA suite cluster (BPM is optional) and also convert BAM to a BAM cluster. This will also work for OIM / OAM cluster. The security store is migrated to a database store during this conversion. To maintain a file based store set a standalone hiera param "retain_security_file_store" to true.

You first need to create some OSB, SOA or BAM clusters and add some managed servers to these clusters for OSB 11g or SOA Suite 11g managed servers make sure to also set the coherence arguments parameters.

A SOA cluster

```puppet
wls_install::utils::fmw_cluster{'soaCluster':
  domain_name       => "soa_domain",
  soa_cluster_name  => "SoaCluster",
  bam_cluster_name  => "BamCluster",
  osb_cluster_name  => "OsbCluster",
  log_output        => true,
  bpm_enabled       => true,
  bam_enabled       => true,
  soa_enabled       => true,
  osb_enabled       => true,
  repository_prefix => "DEV",
}
```

a SOA cluster with ESS

```puppet
wls_install::utils::fmw_cluster{'soaCluster':
  domain_name       => "soa_domain",
  soa_cluster_name  => "SoaCluster",
  bam_cluster_name  => "BamCluster",
  osb_cluster_name  => "OsbCluster",
  ess_cluster_name  => 'EssCluster',
  log_output        => true,
  bpm_enabled       => true,
  bam_enabled       => true,
  soa_enabled       => true,
  osb_enabled       => true,
  b2b_enabled       => true,
  ess_enabled       => true,
  repository_prefix =>=DEV",,
}
```

## fmwclusterjrf
`wls_install::utils::fmwclusterjrf` convert existing cluster to a ADF/JRF cluster. You need to create a wls cluster with some managed servers first.

```puppet
wls_install::utils::fmwclusterjrf{'WebCluster':
  domain_name          => "adf_domain",
  jrf_target_name      => "WebCluster",
  opss_datasource_name => "opss-data-source" #optional,
  log_output           => true,,
  }
```

## webtier
`wls_install::utils::webtier` add an OHS instance to a WebLogic Domain and in the Enterprise Manager, optional with OHS OAM Webgate.

```puppet
# For 11g
wls_install::utils::webtier{'ohs1':
  action_name       => 'create',
  instance_name     => 'ohs1',
  webgate_configure => true,
  log_output        => true,
}

# For 12.1.2
wls_install::utils::webtier{'ohs1':
  action_name       => 'create',
  instance_name     => 'ohs1',
  log_output        => true,
}

# Webtier for OAM
wls_install::utils::webtier{'ohs1':
  action_name            => 'create',
  instance_name          => 'ohs1',
  webgate_configure      => true,
  webgate_agentname      => 'ohs1',
  webgate_hostidentifier => 'host1',
  oamadminserverhostname => 'oim1admin.example.com',
  oamadminserverport     => '7001',
  log_output             => true,
}
```

## oimconfig
`wls_install::utils::oimconfig` Configure OIM , oim server, design or remote configuration

```puppet
wls_install::utils::oimconfig{'oimDomain':
  version                 => 1112,
  oim_home                => '/opt/oracle/middleware11g/Oracle_IDM1',
  server_config           => true,
  oim_password            => 'Welcome01',
  remote_config           => false,
  keystore_password       => 'Welcome01',
  design_config           => false,
  oimserver_hostname      => 'oim1admin.example.com',
  oimserver_port          => '14000',
  repository_database_url => "oimdb.example.com:1521:oimrepos.example.com",
  repository_prefix       => "DEV",
  repository_password     => "Welcome01",
}
```

## instance
`wls_install::oud::instance` Configure OUD (Oracle Unified Directory) ldap instance

```puppet
wls_install::oud::instance{'instance1':
  version                => 1112,
  oud_home               => '/opt/oracle/middleware11g/Oracle_OUD1',
  oud_instance_name      => 'instance1',
  oud_root_user_password => 'Welcome01',
  oud_baseDN             => 'dc=example,dc=com',
  oud_ldapPort           => 1389,
  oud_adminConnectorPort => 4444,
  oud_ldapsPort          => 1636,
  log_output             => *logoutput,
}

wls_install::oud::instance{'instance2':
  version                => 1112,
  oud_home               => '/opt/oracle/middleware11g/Oracle_OUD1',
  oud_instance_name      => 'instance2',
  oud_root_user_password => 'Welcome01',
  oud_baseDN             => 'dc=example,dc=com',
  oud_ldapPort           => 2389,
  oud_adminConnectorPort => 5555,
  oud_ldapsPort          => 2636,
  log_output             => *logoutput,
}
```

## oud_control
`wls_install::oud::control` Stop or start an OUD (Oracle Unified Directory) ldap instance

```puppet
wls_install::oud::control{'instance1':
  oud_instances_home_dir => '/opt/oracle/oud_instances',
  oud_instance_name      => 'instance1',
  action                 => 'start',
  log_output             => true,
}
```

## wls_domain
It needs wls_setting and when identifier is not provided it will use the 'default'. Probably after changing the domain you need to restart the AdminServer or subscribe for a restart to this change with the wls_adminserver type or use puppet resource wls_domain

```puppet
# In this case it will use default as wls_setting identifier
wls_domain { 'Wls1036':
  ensure                                            => 'present',
  jmx_platform_mbean_server_enabled                 => '1',
  jmx_platform_mbean_server_used                    => '1',
  jpa_default_provider                              => 'org.eclipse.persistence.jpa.PersistenceProvider',
  jta_max_transactions                              => '20000',
  jta_transaction_timeout                           => '35',
  log_file_min_size                                 => '5000',
  log_filecount                                     => '10',
  log_filename                                      => '/var/log/weblogic/Wls1036.log',
  log_number_of_files_limited                       => '1',
  log_rotate_logon_startup                          => '1',
  log_rotationtype                                  => 'bySize',
  security_crossdomain                              => '0',
  web_app_container_show_archived_real_path_enabled => '1',
}

wls_domain { 'Wls11gSetting/Wls11g':
  ensure                                            => 'present',
  jmx_platform_mbean_server_enabled                 => '0',
  jmx_platform_mbean_server_used                    => '1',
  jpa_default_provider                              => 'org.apache.openjpa.persistence.PersistenceProviderImpl',
  jta_max_transactions                              => '10000',
  jta_transaction_timeout                           => '30',
  log_file_min_size                                 => '5000',
  log_filecount                                     => '5',
  log_filename                                      => '/var/log/weblogic/Wls11g.log',
  log_number_of_files_limited                       => '0',
  log_rotate_logon_startup                          => '0',
  log_rotationtype                                  => 'byTime',
  security_crossdomain                              => '1',
  web_app_container_show_archived_real_path_enabled => '0',
}
```

## wls_adminserver
Type for adminserver control like start, running, abort and stop.
also supports subscribe with refreshonly

```puppet
# for this type you won't need a wls_setting identifier
wls_adminserver{'AdminServer_Wls1036:':
  ensure                    => 'running',   #running|start|abort|stop
  server_name               => hiera('domain_adminserver'),
  domain_name               => hiera('domain_name'),
  domain_path               => "/opt/oracle/wlsdomains/domains/Wls1036",
  os_user                   => hiera('wls_os_user'),
  weblogic_home_dir         => hiera('wls_weblogic_home_dir'),
  weblogic_user             => hiera('wls_weblogic_user'),
  weblogic_password         => hiera('domain_wls_password'),
  jdk_home_dir              => hiera('wls_jdk_home_dir'),
  nodemanager_address       => hiera('domain_adminserver_address'),
  nodemanager_port          => hiera('domain_nodemanager_port'),
  jsse_enabled              => false,
  custom_trust              => false,
}
```

with JSSE and custom trust

```puppet
# for this type you won't need a wls_setting identifier
wls_adminserver{'AdminServer_Wls1036:':
  ensure                    => 'running',   #running|start|abort|stop
  server_name               => hiera('domain_adminserver'),
  domain_name               => hiera('domain_name'),
  domain_path               => "/opt/oracle/wlsdomains/domains/Wls1036",
  os_user                   => hiera('wls_os_user'),
  weblogic_home_dir         => hiera('wls_weblogic_home_dir'),
  weblogic_user             => hiera('wls_weblogic_user'),
  weblogic_password         => hiera('domain_wls_password'),
  jdk_home_dir              => hiera('wls_jdk_home_dir'),
  nodemanager_address       => hiera('domain_adminserver_address'),
  nodemanager_port          => hiera('domain_nodemanager_port'),
  jsse_enabled              => hiera('wls_jsse_enabled'),
  custom_trust              => hiera('wls_custom_trust'),
  trust_keystore_file       => hiera('wls_trust_keystore_file'),
  trust_keystore_passphrase => hiera('wls_trust_keystore_passphrase'),
}
```

subscribe to a `wls_domain`, `wls_authenticaton_provider` or `wls_identity_asserter` event

```puppet
# for this type you won't need a wls_setting identifier
wls_adminserver{'AdminServer_Wls1036:':
  ensure                    => 'running',   #running|start|abort|stop
  server_name               => hiera('domain_adminserver'),
  domain_name               => hiera('domain_name'),
  domain_path               => "/opt/oracle/wlsdomains/domains/Wls1036",
  os_user                   => hiera('wls_os_user'),
  weblogic_home_dir         => hiera('wls_weblogic_home_dir'),
  weblogic_user             => hiera('wls_weblogic_user'),
  weblogic_password         => hiera('domain_wls_password'),
  jdk_home_dir              => hiera('wls_jdk_home_dir'),
  nodemanager_address       => hiera('domain_adminserver_address'),
  nodemanager_port          => hiera('domain_nodemanager_port'),
  jsse_enabled              => hiera('wls_jsse_enabled'),
  custom_trust              => hiera('wls_custom_trust'),
  trust_keystore_file       => hiera('wls_trust_keystore_file'),
  trust_keystore_passphrase => hiera('wls_trust_keystore_passphrase'),
  refreshonly               => true,
  subscribe                 => Wls_domain['Wls1036'],
}
```

## wls_managedserver
type for managed server control like start, running, abort and stop a managed server or a cluster. Also supports subscribe with refreshonly.

```puppet
# for this type you won't need a wls_setting identifier
wls_managedserver{'JMSServer1_Wls1036:':
  ensure                    => 'running',   #running|start|abort|stop
  target                    => 'Server', #Server|Cluster
  server_name               => 'JMSServer1',
  domain_name               => hiera('domain_name'),
  os_user                   => hiera('wls_os_user'),
  weblogic_home_dir         => hiera('wls_weblogic_home_dir'),
  weblogic_user             => hiera('wls_weblogic_user'),
  weblogic_password         => hiera('domain_wls_password'),
  jdk_home_dir              => hiera('wls_jdk_home_dir'),
  adminserver_address       => hiera('domain_adminserver_address'),
  adminserver_port          => hiera('domain_adminserver_port'),
}
```

Subscribe to a wls_domain, wls_identity_asserter or wls_authenticaton_provider event

```puppet
# for this type you won't need a wls_setting identifier
wls_managedserver{'JMSServer1_Wls1036':
  ensure                    => 'running',   #running|start|abort|stop
  target                    => 'Server',    #Server|Cluster
  server_name               => 'JMSServer1',
  domain_name               => hiera('domain_name'),
  os_user                   => hiera('wls_os_user'),
  weblogic_home_dir         => hiera('wls_weblogic_home_dir'),
  weblogic_user             => hiera('wls_weblogic_user'),
  weblogic_password         => hiera('domain_wls_password'),
  jdk_home_dir              => hiera('wls_jdk_home_dir'),
  adminserver_address       => hiera('domain_adminserver_address'),
  adminserver_port          => hiera('domain_adminserver_port'),
  refreshonly               => true,
  subscribe                 => Wls_domain['Wls1036'],
}
```


## wls_install::support::files

This class creates the standard startup files for your weblogic installation. You can use it:

```puppet
include wls_install::support::files
```

If you need to override the defaults which does not match with your environment and call the class `wls_install::support::files` with the necessary parameters:

use:

```puppet

class{'wls_install::support::files':
    os_oracle_home      => "/opt/oracle",
    ora_inventory       => "/opt/oracle/oraInventory",
    os_domain_type      => "soa", # soa|admin|web|oim
    os_log_folder       => "/data/logs",
    os_download_folder  => "/data/install",
    os_mdw_home         => "/opt/oracle/wls/Middleware11gR1",
    os_wl_home          => "/opt/oracle/wls/Middleware11gR1/wlserver_10.3",
    ora_user            => "oracle",
    ora_group           => "dba",
    os_domain           => "osbSoaDomain",
    os_domain_path      => "/opt/oracle/wls/Middleware11gR1/user_projects/domains/osbSoaDomain",
    node_mgr_path       => "/opt/oracle/wls/Middleware11gR1/wlserver_10.3/server/bin",
    node_mgr_port       => 5556,
    node_mgr_address    => 'localhost',
    wls_user            => "weblogic",
    wls_password        => "weblogic1",
    wls_adminserver     => "AdminServer",
    jsse_enabled        => false,
}
```
It will add WebLogic the next set of scripts to /opt/scripts/wls

**cleanOracleEnvironment.sh**
Remove all Oracle WebLogic existence so you can deploy again
Actions
1. Remove domain pack files, ${osDownloadFolder}/domain_*.*
2. Remove mdwhome, $osOracleHome
3. Remove beahome list of user $oraUser
4. Remove /etc/oraInst.loc
5. Remove ${osDownloadFolder}/osb
6. Remove ${osDownloadFolder}/soa
7  Remove ${osDownloadFolder}/*.xml

**showStatus.sh**
1. Shows if the AdminServer, Soa and OSB server is running plus the PIDs
2. Shows if the NodeManager is running plus the PID

**startNodeManager.sh**
Starts the nodemanager

**stopNodeManager.sh**
Stops the nodemanager

**startWeblogicAdmin.sh**
1. Checks first if the nodemanager is running
2. Check if the AdminServer is already started
3. Start the WebLogic Adminserver from the nodemanager

**stopWeblogicAdmin.sh**
1. Checks first if the nodemanager is running
2. Check if the AdminServer is running
3. Stops the WebLogic Adminserver from the nodemanager


## wls_install::support::nodemanagerautostart

install auto start script for the nodemanager of WebLogic ( 10.3, 11g, 12.1.1 ) or 12.1.2.

### for WebLogic 12.1.2 and higher

```puppet
wls_install::support::nodemanagerautostart{"autostart ${wlsDomainName}":
  version      => 1212,
  wl_home      => '/opt/oracle/middleware12c/wlserver',
  user         => 'oracle',
  domain       => 'Wls1212',
  domain_path  => '/opt/oracle/middleware12c/user_projects/domains/Wls1212'
}
```

### for WebLogic 10 or 11g

```puppet
wls_install::support::nodemanagerautostart{"autostart weblogic 11g":
  version     => 1111,
  wl_home     => "/opt/oracle/middleware11g/wlserver_10.3",
  user        => 'wls',
}
```

### using JSSE and custom trust

```pupppet
wls_install::support::nodemanagerautostart{"autostart weblogic 11g":
  version                   => 1111,
  wl_home                   => "/opt/oracle/middleware11g/wlserver_10.3",
  user                      => 'oracle',
  jsse_enabled              => true,
  custom_trust              => true,
  trust_keystore_file       => '/vagrant/truststore.jks',
  trust_keystore_passphrase => 'XXX',
}
```
