---
title: fmw
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview


This defined type allows you to install the Fusion Middleware add-on software. It supports:

- OSB
- SOA Suite
- WebTier (HTTP Server)
- Oracle Identity Management
- Web Center + Content

Here is an example on how you could use this:

```puppet
orawls::fmw{"osbPS6":
  middleware_home_dir     => "/opt/oracle/middleware11gR1",
  weblogic_home_dir       => "/opt/oracle/middleware11gR1/wlserver",
  jdk_home_dir            => "/usr/java/jdk1.7.0_45",
  oracle_base_home_dir    => "/opt/oracle",
  fmw_product             => "osb",  # adf|soa|osb|oim|wc|wcc|web
  fmw_file1               => "ofm_osb_generic_11.1.1.7.0_disk1_1of1.zip",
  os_user                 => "oracle",
  os_group                => "dba",
  download_dir            => "/data/install",
  source                  => "/vagrant",
}
```




## Attributes



Attribute Name                                    | Short Description                                                                                 |
------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[bpm](#fmw_bpm)                                   | Boolean to determine if you want to enable BPM.                                                   |
[download_dir](#fmw_download_dir)                 | The directory where the Puppet software puts all downloaded files.                                |
[fmw_file1](#fmw_fmw_file1)                       | First file of FMW distribution.                                                                   |
[fmw_file2](#fmw_fmw_file2)                       | Second file of FMW distribution.                                                                  |
[fmw_file3](#fmw_fmw_file3)                       | Third file of FMW distribution.                                                                   |
[fmw_file4](#fmw_fmw_file4)                       | Fourth file of FMW distribution.                                                                  |
[fmw_product](#fmw_fmw_product)                   | Type of Fusion Middleware Product you want to install.                                            |
[healthcare](#fmw_healthcare)                     | Boolean to determine if you want to enable healthcare.                                            |
[jdk_home_dir](#fmw_jdk_home_dir)                 | The homdirectory for the Java evelopment Kit.                                                     |
[log_output](#fmw_log_output)                     | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#fmw_logoutput)                       | log the outputs of Puppet exec or not.                                                            |
[middleware_home_dir](#fmw_middleware_home_dir)   | Middleware home directory.                                                                        |
[ohs_mode](#fmw_ohs_mode)                         | Type of OHS mode.                                                                                 |
[oracle_base_home_dir](#fmw_oracle_base_home_dir) | A directory to use as Oracle base directory.                                                      |
[oracle_home_dir](#fmw_oracle_home_dir)           | A directory to be used as Oracle home directory for this software.                                |
[oracle_inventory_dir](#fmw_oracle_inventory_dir) | The directory that contains the oracle inventory.                                                 |
[orainstpath_dir](#fmw_orainstpath_dir)           | Path where to find the oraint.loc file.                                                           |
[os_group](#fmw_os_group)                         | The os group used to install and run WebLogic.                                                    |
[os_user](#fmw_os_user)                           | The os user used to install and run WebLogic.                                                     |
[remote_file](#fmw_remote_file)                   | This parameter is not being used anymore and will be removed in a future release.                 |
[source](#fmw_source)                             | Source for the operation.                                                                         |
[temp_directory](#fmw_temp_directory)             | Directory to use for temporary files.                                                             |
[version](#fmw_version)                           | The version that is installed in the used Oracle home.                                            |
[weblogic_home_dir](#fmw_weblogic_home_dir)       | Directory to use as WebLogic home.                                                                |




### version<a name='fmw_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Wls_install::Versions`

Default:`lookup({name => 'wls_version', default_value => 1111})`

[Back to overview of fmw](#attributes)

### weblogic_home_dir<a name='fmw_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir'})`

[Back to overview of fmw](#attributes)

### middleware_home_dir<a name='fmw_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_middleware_home_dir'})`

[Back to overview of fmw](#attributes)

### oracle_base_home_dir<a name='fmw_oracle_base_home_dir'>

A directory to use as Oracle base directory.


Type: `Optional[Stdlib::Absolutepath]`

Default:`lookup({name => 'wls_oracle_base_home_dir'})`

[Back to overview of fmw](#attributes)

### oracle_home_dir<a name='fmw_oracle_home_dir'>

A directory to be used as Oracle home directory for this software.


Type: `Optional[Stdlib::Absolutepath]`

Default:`undef`

[Back to overview of fmw](#attributes)

### jdk_home_dir<a name='fmw_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir'})`

[Back to overview of fmw](#attributes)

### fmw_product<a name='fmw_fmw_product'>

Type of Fusion Middleware Product you want to install.

Valid values are:

- adf
- soa
- soaqs
- osb
- wcc
- wc
- oim
- oam
- web
- webgate
- oud
- mft
- b2b
- forms

Type: `Enum[
    'adf',
    'soa',
    'soaqs',
    'osb',
    'wcc',
    'wc',
    'oim',
    'oam',
    'web',
    'webgate',
    'oud',
    'mft',
    'b2b',
    'forms'
  ]`

Default:`undef`

[Back to overview of fmw](#attributes)

### fmw_file1<a name='fmw_fmw_file1'>

First file of FMW distribution.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of fmw](#attributes)

### fmw_file2<a name='fmw_fmw_file2'>

Second file of FMW distribution.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of fmw](#attributes)

### fmw_file3<a name='fmw_fmw_file3'>

Third file of FMW distribution.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of fmw](#attributes)

### fmw_file4<a name='fmw_fmw_file4'>

Fourth file of FMW distribution.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of fmw](#attributes)

### bpm<a name='fmw_bpm'>

Boolean to determine if you want to enable BPM.

Type: `Boolean`

Default:`false`

[Back to overview of fmw](#attributes)

### healthcare<a name='fmw_healthcare'>

Boolean to determine if you want to enable healthcare.

Type: `Boolean`

Default:`false`

[Back to overview of fmw](#attributes)

### os_user<a name='fmw_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of fmw](#attributes)

### os_group<a name='fmw_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of fmw](#attributes)

### download_dir<a name='fmw_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of fmw](#attributes)

### source<a name='fmw_source'>

Source for the operation.

Type: `String[1]`

Default:`lookup({name => 'wls_source', default_value => undef})`

[Back to overview of fmw](#attributes)

### temp_directory<a name='fmw_temp_directory'>

Directory to use for temporary files.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_temp_dir', default_value => '/tmp'})`

[Back to overview of fmw](#attributes)

### ohs_mode<a name='fmw_ohs_mode'>

Type of OHS mode.

Valid values are:

- colocated
- collocated
- standalone
 
Type: `Enum[
    'colocated',
    'collocated',
    'standalone'
  ]`

Default:`lookup({name => 'ohs_mode', default_value => 'collocated'})`

[Back to overview of fmw](#attributes)

### oracle_inventory_dir<a name='fmw_oracle_inventory_dir'>

The directory that contains the oracle inventory.

The default value is: `/oracle_base/oraInventory`

Type: `Optional[Stdlib::Absolutepath]`

Default:`undef`

[Back to overview of fmw](#attributes)

### orainstpath_dir<a name='fmw_orainstpath_dir'>

Path where to find the oraint.loc file.

Type: `Optional[Stdlib::Absolutepath]`

Default:`lookup({name => 'orainstpath_dir', default_value => undef})`

[Back to overview of fmw](#attributes)

### logoutput<a name='fmw_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of fmw](#attributes)

### log_output<a name='fmw_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum[
        'on_failure'
      ]
    ]
  ]`

Default:`undef`

[Back to overview of fmw](#attributes)

### remote_file<a name='fmw_remote_file'>

**DEPRECATED**
This parameter is not being used anymore and will be removed in a future release.

`true`.

Type: `Optional[Boolean]`

Default:`undef`

[Back to overview of fmw](#attributes)
