---
title: fmwcluster
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview

This defined type allows you to convert an existing cluster into a OSB or SOA suite cluster (BPM is optional) and also convert BAM to a BAM cluster. This will also work for OIM / OAM cluster. Here is an example on how you could use this:

```puppet
ora_install::fmwcluster { 'soaCluster':
  domain_name       => "soa_domain",
  soa_cluster_name  => "SoaCluster",
  bam_cluster_name  => "BamCluster",
  osb_cluster_name  => "OsbCluster",
  log_output        => *logoutput,
  bpm_enabled       => true,
  bam_enabled       => true,
  soa_enabled       => true,
  osb_enabled       => true,
  repository_prefix => "DEV",
}
```





## Attributes



Attribute Name                                                         | Short Description                                                                                 |
---------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[adminserver_address](#fmwcluster_adminserver_address)                 | The address of the admin server.                                                                  |
[adminserver_name](#fmwcluster_adminserver_name)                       | The name of the Admin Server.                                                                     |
[adminserver_port](#fmwcluster_adminserver_port)                       | The IP port the admin server is listening on.                                                     |
[b2b_enabled](#fmwcluster_b2b_enabled)                                 | Boolean to determine if b2b is enabled.                                                           |
[bam_cluster_name](#fmwcluster_bam_cluster_name)                       | Name of the cluster to target BAM managed servers on.                                             |
[bam_enabled](#fmwcluster_bam_enabled)                                 | Boolean to determine if bam is enabled.                                                           |
[bi_cluster_name](#fmwcluster_bi_cluster_name)                         | Name of the cluster to target BI managed servers on.                                              |
[bi_enabled](#fmwcluster_bi_enabled)                                   | Boolean to determine if bi is enabled.                                                            |
[bpm_enabled](#fmwcluster_bpm_enabled)                                 | Boolean to determine if bpm is enabled.                                                           |
[custom_trust](#fmwcluster_custom_trust)                               | Determine if you want to use a custom trust or not.                                               |
[domain_name](#fmwcluster_domain_name)                                 | The domain name.                                                                                  |
[download_dir](#fmwcluster_download_dir)                               | The directory where the Puppet software puts all downloaded files.                                |
[ess_cluster_name](#fmwcluster_ess_cluster_name)                       | Name of the cluster to target ESS managed servers on.                                             |
[ess_enabled](#fmwcluster_ess_enabled)                                 | Boolean to determine if ess is enabled.                                                           |
[jdk_home_dir](#fmwcluster_jdk_home_dir)                               | The homdirectory for the Java evelopment Kit.                                                     |
[jsse_enabled](#fmwcluster_jsse_enabled)                               | Determine if you want to enable JSSE security.                                                    |
[log_output](#fmwcluster_log_output)                                   | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#fmwcluster_logoutput)                                     | log the outputs of Puppet exec or not.                                                            |
[middleware_home_dir](#fmwcluster_middleware_home_dir)                 | Middleware home directory.                                                                        |
[nodemanager_port](#fmwcluster_nodemanager_port)                       | The IP port the nodemanager is listening on.                                                      |
[nodemanager_secure_listener](#fmwcluster_nodemanager_secure_listener) | Use SSL for listening.                                                                            |
[oam_cluster_name](#fmwcluster_oam_cluster_name)                       | Name of the cluster to target OAM managed servers on.                                             |
[oam_enabled](#fmwcluster_oam_enabled)                                 | Boolean to determine if oam is enabled.                                                           |
[ofm_version](#fmwcluster_ofm_version)                                 | Version of OFM to use.                                                                            |
[oim_cluster_name](#fmwcluster_oim_cluster_name)                       | Name of the cluster to target OIM managed servers on.                                             |
[oim_enabled](#fmwcluster_oim_enabled)                                 | Boolean to determine if oim is enabled.                                                           |
[os_group](#fmwcluster_os_group)                                       | The os group used to install and run WebLogic.                                                    |
[os_user](#fmwcluster_os_user)                                         | The os user used to install and run WebLogic.                                                     |
[osb_cluster_name](#fmwcluster_osb_cluster_name)                       | Name of the cluster to target OSB managed servers on.                                             |
[osb_enabled](#fmwcluster_osb_enabled)                                 | Boolean to determine if osb is enabled.                                                           |
[repository_prefix](#fmwcluster_repository_prefix)                     | Extra prefix to use for the RCU.                                                                  |
[retain_file_store](#fmwcluster_retain_file_store)                     | Boolean to determine if you want to retain the security file store.                               |
[soa_cluster_name](#fmwcluster_soa_cluster_name)                       | Name of the cluster to target SOA managed servers on.                                             |
[soa_enabled](#fmwcluster_soa_enabled)                                 | Boolean to determine if soa is enabled.                                                           |
[trust_keystore_file](#fmwcluster_trust_keystore_file)                 | File specificiation of the trust keystore.                                                        |
[trust_keystore_passphrase](#fmwcluster_trust_keystore_passphrase)     | Passphrase to use for the trust keystore.                                                         |
[version](#fmwcluster_version)                                         | The version that is installed in the used Oracle home.                                            |
[weblogic_home_dir](#fmwcluster_weblogic_home_dir)                     | Directory to use as WebLogic home.                                                                |
[weblogic_password](#fmwcluster_weblogic_password)                     | The password of the base WebLogic user name.                                                      |
[weblogic_user](#fmwcluster_weblogic_user)                             | The base WebLogic username to configure.                                                          |
[wls_domains_dir](#fmwcluster_wls_domains_dir)                         | The root directory where all domain directories reside in.                                        |




### version<a name='fmwcluster_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Wls_install::Versions`

Default:`lookup({name => 'wls_version', default_value => 1111})`

[Back to overview of fmwcluster](#attributes)

### ofm_version<a name='fmwcluster_ofm_version'>

Version of OFM to use.

Type: `Variant[
    Integer[1116,1116],
    Integer[1117,1117]
  ]`

Default:`lookup({name => 'ofm_version', default_value => 1117})`

[Back to overview of fmwcluster](#attributes)

### weblogic_home_dir<a name='fmwcluster_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir'})`

[Back to overview of fmwcluster](#attributes)

### middleware_home_dir<a name='fmwcluster_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_middleware_home_dir'})`

[Back to overview of fmwcluster](#attributes)

### jdk_home_dir<a name='fmwcluster_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir'})`

[Back to overview of fmwcluster](#attributes)

### wls_domains_dir<a name='fmwcluster_wls_domains_dir'>

The root directory where all domain directories reside in.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_domains_dir', default_value => undef})`

[Back to overview of fmwcluster](#attributes)

### domain_name<a name='fmwcluster_domain_name'>

The domain name.

Type: `String[1]`

Default:`lookup({name => 'domain_name'})`

[Back to overview of fmwcluster](#attributes)

### adminserver_name<a name='fmwcluster_adminserver_name'>

The name of the Admin Server.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver', default_value => 'AdminServer'})`

[Back to overview of fmwcluster](#attributes)

### adminserver_address<a name='fmwcluster_adminserver_address'>

The address of the admin server. May be a DNS name or a physical IP address.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver_address', default_value => 'localhost'})`

[Back to overview of fmwcluster](#attributes)

### adminserver_port<a name='fmwcluster_adminserver_port'>

The IP port the admin server is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_adminserver_port', default_value => 7001})`

[Back to overview of fmwcluster](#attributes)

### nodemanager_port<a name='fmwcluster_nodemanager_port'>

The IP port the nodemanager is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_nodemanager_port', default_value => 5556})`

[Back to overview of fmwcluster](#attributes)

### soa_cluster_name<a name='fmwcluster_soa_cluster_name'>

Name of the cluster to target SOA managed servers on.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of fmwcluster](#attributes)

### bam_cluster_name<a name='fmwcluster_bam_cluster_name'>

Name of the cluster to target BAM managed servers on.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of fmwcluster](#attributes)

### osb_cluster_name<a name='fmwcluster_osb_cluster_name'>

Name of the cluster to target OSB managed servers on.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of fmwcluster](#attributes)

### oam_cluster_name<a name='fmwcluster_oam_cluster_name'>

Name of the cluster to target OAM managed servers on.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of fmwcluster](#attributes)

### oim_cluster_name<a name='fmwcluster_oim_cluster_name'>

Name of the cluster to target OIM managed servers on.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of fmwcluster](#attributes)

### ess_cluster_name<a name='fmwcluster_ess_cluster_name'>

Name of the cluster to target ESS managed servers on.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of fmwcluster](#attributes)

### bi_cluster_name<a name='fmwcluster_bi_cluster_name'>

Name of the cluster to target BI managed servers on.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of fmwcluster](#attributes)

### bpm_enabled<a name='fmwcluster_bpm_enabled'>

Boolean to determine if bpm is enabled.

Type: `Boolean`

Default:`false`

[Back to overview of fmwcluster](#attributes)

### bam_enabled<a name='fmwcluster_bam_enabled'>

Boolean to determine if bam is enabled.

Type: `Boolean`

Default:`false`

[Back to overview of fmwcluster](#attributes)

### osb_enabled<a name='fmwcluster_osb_enabled'>

Boolean to determine if osb is enabled.

Type: `Boolean`

Default:`false`

[Back to overview of fmwcluster](#attributes)

### soa_enabled<a name='fmwcluster_soa_enabled'>

Boolean to determine if soa is enabled.

Type: `Boolean`

Default:`false`

[Back to overview of fmwcluster](#attributes)

### oam_enabled<a name='fmwcluster_oam_enabled'>

Boolean to determine if oam is enabled.

Type: `Boolean`

Default:`false`

[Back to overview of fmwcluster](#attributes)

### oim_enabled<a name='fmwcluster_oim_enabled'>

Boolean to determine if oim is enabled.

Type: `Boolean`

Default:`false`

[Back to overview of fmwcluster](#attributes)

### b2b_enabled<a name='fmwcluster_b2b_enabled'>

Boolean to determine if b2b is enabled.

Type: `Boolean`

Default:`false`

[Back to overview of fmwcluster](#attributes)

### ess_enabled<a name='fmwcluster_ess_enabled'>

Boolean to determine if ess is enabled.

Type: `Boolean`

Default:`false`

[Back to overview of fmwcluster](#attributes)

### bi_enabled<a name='fmwcluster_bi_enabled'>

Boolean to determine if bi is enabled.

Type: `Boolean`

Default:`false`

[Back to overview of fmwcluster](#attributes)

### repository_prefix<a name='fmwcluster_repository_prefix'>

Extra prefix to use for the RCU.

Type: `String[1]`

Default:`lookup({name => 'repository_prefix', default_value => 'DEV'})`

[Back to overview of fmwcluster](#attributes)

### weblogic_user<a name='fmwcluster_weblogic_user'>

The base WebLogic username to configure.

Type: `String[1]`

Default:`lookup({name => 'wls_weblogic_user', default_value => 'weblogic'})`

[Back to overview of fmwcluster](#attributes)

### weblogic_password<a name='fmwcluster_weblogic_password'>

The password of the base WebLogic user name.

Type: `String[1]`

Default:`lookup({name => 'domain_wls_password'})`

[Back to overview of fmwcluster](#attributes)

### os_user<a name='fmwcluster_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of fmwcluster](#attributes)

### os_group<a name='fmwcluster_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of fmwcluster](#attributes)

### download_dir<a name='fmwcluster_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of fmwcluster](#attributes)

### retain_file_store<a name='fmwcluster_retain_file_store'>

Boolean to determine if you want to retain the security file store. This is useful only for soa suite 1036 or 1111 and not if OAM is already installed.

Type: `Boolean`

Default:`lookup({name => 'retain_security_file_store', default_value => false})`

[Back to overview of fmwcluster](#attributes)

### jsse_enabled<a name='fmwcluster_jsse_enabled'>

Determine if you want to enable JSSE security.

Type: `Boolean`

Default:`lookup({name => 'wls_jsse_enabled', default_value => false})`

[Back to overview of fmwcluster](#attributes)

### custom_trust<a name='fmwcluster_custom_trust'>

Determine if you want to use a custom trust or not.

Type: `Boolean`

Default:`lookup({name => 'wls_custom_trust', default_value => false})`

[Back to overview of fmwcluster](#attributes)

### trust_keystore_file<a name='fmwcluster_trust_keystore_file'>

File specificiation of the trust keystore.


Type: `Optional[String[1]]`

Default:`lookup({name => 'wls_trust_keystore_file', default_value => undef})`

[Back to overview of fmwcluster](#attributes)

### trust_keystore_passphrase<a name='fmwcluster_trust_keystore_passphrase'>

Passphrase to use for the trust keystore.

Type: `Optional[String[1]]`

Default:`lookup({name => 'wls_trust_keystore_passphrase', default_value => undef})`

[Back to overview of fmwcluster](#attributes)

### nodemanager_secure_listener<a name='fmwcluster_nodemanager_secure_listener'>

Use SSL for listening.

Type: `Boolean`

Default:`true`

[Back to overview of fmwcluster](#attributes)

### logoutput<a name='fmwcluster_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of fmwcluster](#attributes)

### log_output<a name='fmwcluster_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum['on_failure']
    ]
  ]`

Default:`undef`

[Back to overview of fmwcluster](#attributes)
