---
title: nodemanager
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview

This defined type allows you to start a nodemanager on a system. Here is an example on how you could use this:

```puppet
ora_install::nodemanager{'nodemanager12c':
  version                     => 1212, # 1036|1111|1211|1212
  weblogic_home_dir           => "/opt/oracle/middleware12c/wlserver",
  jdk_home_dir                => "/usr/java/jdk1.7.0_45",
  nodemanager_port            => 5556,
  nodemanager_secure_listener => true,
  domain_name                 => "Wls12c",
  os_user                     => "oracle",
  os_group                    => "dba",
  log_dir                     => "/data/logs",
  download_dir                => "/data/install",
  log_output                  => true,
  sleep                       => 20,
  properties                  => {},
}
```





## Attributes



Attribute Name                                                                              | Short Description                                                                                 |
------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[custom_identity](#nodemanager_custom_identity)                                             | Determine if you want to use a custom identity store or not.                                      |
[custom_identity_alias](#nodemanager_custom_identity_alias)                                 | Alias for custom identity.                                                                        |
[custom_identity_keystore_filename](#nodemanager_custom_identity_keystore_filename)         | file name of the keystore identity file.                                                          |
[custom_identity_keystore_passphrase](#nodemanager_custom_identity_keystore_passphrase)     | Passphrase to use when opening the identity keystore.                                             |
[custom_identity_privatekey_passphrase](#nodemanager_custom_identity_privatekey_passphrase) | Private passphrase to use when opening the identity keystore.                                     |
[custom_trust](#nodemanager_custom_trust)                                                   | Determine if you want to use a custom trust or not.                                               |
[domain_name](#nodemanager_domain_name)                                                     | The domain name.                                                                                  |
[download_dir](#nodemanager_download_dir)                                                   | The directory where the Puppet software puts all downloaded files.                                |
[extra_arguments](#nodemanager_extra_arguments)                                             | Extra java arguments to use.                                                                      |
[jdk_home_dir](#nodemanager_jdk_home_dir)                                                   | The homdirectory for the Java evelopment Kit.                                                     |
[jsse_enabled](#nodemanager_jsse_enabled)                                                   | Determine if you want to enable JSSE security.                                                    |
[log_dir](#nodemanager_log_dir)                                                             | Directory to use for logging.                                                                     |
[log_file](#nodemanager_log_file)                                                           | Log file to use.                                                                                  |
[log_output](#nodemanager_log_output)                                                       | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#nodemanager_logoutput)                                                         | log the outputs of Puppet exec or not.                                                            |
[middleware_home_dir](#nodemanager_middleware_home_dir)                                     | Middleware home directory.                                                                        |
[nodemanager_address](#nodemanager_nodemanager_address)                                     | Address the nodemanager is running on.                                                            |
[nodemanager_port](#nodemanager_nodemanager_port)                                           | The IP port the nodemanager is listening on.                                                      |
[nodemanager_secure_listener](#nodemanager_nodemanager_secure_listener)                     | Use SSL for listening.                                                                            |
[ohs_standalone](#nodemanager_ohs_standalone)                                               | Boolean to determine if you want to use OHS standalone mode.                                      |
[os_group](#nodemanager_os_group)                                                           | The os group used to install and run WebLogic.                                                    |
[os_user](#nodemanager_os_user)                                                             | The os user used to install and run WebLogic.                                                     |
[properties](#nodemanager_properties)                                                       | Properties to use.                                                                                |
[puppet_os_user](#nodemanager_puppet_os_user)                                               | The Puppet OS user to use.                                                                        |
[sleep](#nodemanager_sleep)                                                                 | Maximum time to wait to check if nodemanger is running correctly.                                 |
[trust_keystore_file](#nodemanager_trust_keystore_file)                                     | File specificiation of the trust keystore.                                                        |
[trust_keystore_passphrase](#nodemanager_trust_keystore_passphrase)                         | Passphrase to use for the trust keystore.                                                         |
[version](#nodemanager_version)                                                             | The version that is installed in the used Oracle home.                                            |
[weblogic_home_dir](#nodemanager_weblogic_home_dir)                                         | Directory to use as WebLogic home.                                                                |
[wls_domains_dir](#nodemanager_wls_domains_dir)                                             | The root directory where all domain directories reside in.                                        |




### version<a name='nodemanager_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Wls_install::Versions`

Default:`lookup({name => 'wls_version', default_value => 1111})`

[Back to overview of nodemanager](#attributes)

### middleware_home_dir<a name='nodemanager_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_middleware_home_dir'})`

[Back to overview of nodemanager](#attributes)

### weblogic_home_dir<a name='nodemanager_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir'})`

[Back to overview of nodemanager](#attributes)

### nodemanager_port<a name='nodemanager_nodemanager_port'>

The IP port the nodemanager is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_nodemanager_port', default_value => 5556})`

[Back to overview of nodemanager](#attributes)

### nodemanager_address<a name='nodemanager_nodemanager_address'>

Address the nodemanager is running on. This may be a DNS name or a physical IP address.

Type: `String[1]`

Default:`undef`

[Back to overview of nodemanager](#attributes)

### nodemanager_secure_listener<a name='nodemanager_nodemanager_secure_listener'>

Use SSL for listening.

Type: `Boolean`

Default:`true`

[Back to overview of nodemanager](#attributes)

### jsse_enabled<a name='nodemanager_jsse_enabled'>

Determine if you want to enable JSSE security.

Type: `Boolean`

Default:`lookup({name => 'wls_jsse_enabled', default_value => false})`

[Back to overview of nodemanager](#attributes)

### custom_trust<a name='nodemanager_custom_trust'>

Determine if you want to use a custom trust or not.

Type: `Boolean`

Default:`lookup({name => 'wls_custom_trust', default_value => false})`

[Back to overview of nodemanager](#attributes)

### trust_keystore_file<a name='nodemanager_trust_keystore_file'>

File specificiation of the trust keystore.


Type: `Optional[String[1]]`

Default:`lookup({name => 'wls_trust_keystore_file', default_value => undef})`

[Back to overview of nodemanager](#attributes)

### trust_keystore_passphrase<a name='nodemanager_trust_keystore_passphrase'>

Passphrase to use for the trust keystore.

Type: `Optional[String[1]]`

Default:`lookup({name => 'wls_trust_keystore_passphrase', default_value => undef})`

[Back to overview of nodemanager](#attributes)

### custom_identity<a name='nodemanager_custom_identity'>

Determine if you want to use a custom identity store or not.

Type: `Boolean`

Default:`false`

[Back to overview of nodemanager](#attributes)

### custom_identity_keystore_filename<a name='nodemanager_custom_identity_keystore_filename'>

file name of the keystore identity file.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of nodemanager](#attributes)

### custom_identity_keystore_passphrase<a name='nodemanager_custom_identity_keystore_passphrase'>

Passphrase to use when opening the identity keystore.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of nodemanager](#attributes)

### custom_identity_alias<a name='nodemanager_custom_identity_alias'>

Alias for custom identity.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of nodemanager](#attributes)

### custom_identity_privatekey_passphrase<a name='nodemanager_custom_identity_privatekey_passphrase'>

Private passphrase to use when opening the identity keystore.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of nodemanager](#attributes)

### extra_arguments<a name='nodemanager_extra_arguments'>

Extra java arguments to use.

Type: `String`

Default:`''`

[Back to overview of nodemanager](#attributes)

### wls_domains_dir<a name='nodemanager_wls_domains_dir'>

The root directory where all domain directories reside in.

Type: `Optional[
    Stdlib::Absolutepath
  ]`

Default:`lookup({name => 'wls_domains_dir', default_value => undef})`

[Back to overview of nodemanager](#attributes)

### domain_name<a name='nodemanager_domain_name'>

The domain name.

Type: `Optional[
    String[1]]`

Default:`lookup({name => 'domain_name', default_value => undef})`

[Back to overview of nodemanager](#attributes)

### jdk_home_dir<a name='nodemanager_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir'})`

[Back to overview of nodemanager](#attributes)

### os_user<a name='nodemanager_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of nodemanager](#attributes)

### os_group<a name='nodemanager_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of nodemanager](#attributes)

### download_dir<a name='nodemanager_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of nodemanager](#attributes)

### log_dir<a name='nodemanager_log_dir'>

Directory to use for logging.

Type: `Optional[
    Stdlib::Absolutepath
  ]`

Default:`lookup({name => 'wls_log_dir', default_value => undef})`

[Back to overview of nodemanager](#attributes)

### log_file<a name='nodemanager_log_file'>

Log file to use.

Type: `String[1]`

Default:`'nodemanager.log'`

[Back to overview of nodemanager](#attributes)

### sleep<a name='nodemanager_sleep'>

Maximum time to wait to check if nodemanger is running correctly. If time expires, the type will fail.

Type: `Integer`

Default:`lookup({name => 'wls_nodemanager_sleep', default_value => 20})`

[Back to overview of nodemanager](#attributes)

### properties<a name='nodemanager_properties'>

Properties to use.

Type: `Hash`

Default:`{}`

[Back to overview of nodemanager](#attributes)

### ohs_standalone<a name='nodemanager_ohs_standalone'>

Boolean to determine if you want to use OHS standalone mode.

Type: `Boolean`

Default:`false`

[Back to overview of nodemanager](#attributes)

### puppet_os_user<a name='nodemanager_puppet_os_user'>

The Puppet OS user to use.

Type: `String[1]`

Default:`lookup({name => 'puppet_os_user', default_value => 'root'})`

[Back to overview of nodemanager](#attributes)

### logoutput<a name='nodemanager_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of nodemanager](#attributes)

### log_output<a name='nodemanager_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum[
        'on_failure'
      ]
    ]
  ]`

Default:`undef`

[Back to overview of nodemanager](#attributes)
