---
title: nodemanagerautostart
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview


This defined type allows you to add the nodemanager startup scripts to the system. Here is an example on how you could use this:

```puppet
ora_install::support::nodemanagerautostart{"autostart ${wlsDomainName}":
  version      => 1212,
  wl_home      => '/opt/oracle/middleware12c/wlserver',
  user         => 'oracle',
  domain       => 'Wls1212',
  domain_path  => '/opt/oracle/middleware12c/user_projects/domains/Wls1212'
```




## Attributes



Attribute Name                                                               | Short Description                                      |
---------------------------------------------------------------------------- | ------------------------------------------------------ |
[custom_trust](#nodemanagerautostart_custom_trust)                           | Determine if you want to use a custom trust or not.    |
[domain](#nodemanagerautostart_domain)                                       | Domain name.                                           |
[domain_path](#nodemanagerautostart_domain_path)                             | Path where the domain inforrmation is stored.          |
[jsse_enabled](#nodemanagerautostart_jsse_enabled)                           | Determine if you want to enable JSSE security.         |
[log_dir](#nodemanagerautostart_log_dir)                                     | Directory to use for logging.                          |
[systemd_script_location](#nodemanagerautostart_systemd_script_location)     | Location to put the systemd script.                    |
[trust_keystore_file](#nodemanagerautostart_trust_keystore_file)             | File specificiation of the trust keystore.             |
[trust_keystore_passphrase](#nodemanagerautostart_trust_keystore_passphrase) | Passphrase to use for the trust keystore.              |
[user](#nodemanagerautostart_user)                                           | The user used for the specified installation.          |
[version](#nodemanagerautostart_version)                                     | The version that is installed in the used Oracle home. |
[wl_home](#nodemanagerautostart_wl_home)                                     | WebLogic home directory.                               |




### version<a name='nodemanagerautostart_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Wls_install::Versions`

Default:`1111`

[Back to overview of nodemanagerautostart](#attributes)

### wl_home<a name='nodemanagerautostart_wl_home'>

WebLogic home directory.

Type: `Stdlib::Absolutepath`

Default:`undef`

[Back to overview of nodemanagerautostart](#attributes)

### user<a name='nodemanagerautostart_user'>

The user used for the specified installation.
The install class will not create the user for you. You must do that yourself.

The default value is: `oracle`

Type: `String[1]`

Default:`'oracle'`

[Back to overview of nodemanagerautostart](#attributes)

### domain<a name='nodemanagerautostart_domain'>

Domain name.

Type: `String[1]`

Default:`undef`

[Back to overview of nodemanagerautostart](#attributes)

### domain_path<a name='nodemanagerautostart_domain_path'>

Path where the domain inforrmation is stored.

Type: `String[1]`

Default:`undef`

[Back to overview of nodemanagerautostart](#attributes)

### log_dir<a name='nodemanagerautostart_log_dir'>

Directory to use for logging.

Type: `Stdlib::Absolutepath`

Default:`undef`

[Back to overview of nodemanagerautostart](#attributes)

### jsse_enabled<a name='nodemanagerautostart_jsse_enabled'>

Determine if you want to enable JSSE security.

Type: `Boolean`

Default:`false`

[Back to overview of nodemanagerautostart](#attributes)

### custom_trust<a name='nodemanagerautostart_custom_trust'>

Determine if you want to use a custom trust or not.

Type: `Boolean`

Default:`false`

[Back to overview of nodemanagerautostart](#attributes)

### trust_keystore_file<a name='nodemanagerautostart_trust_keystore_file'>

File specificiation of the trust keystore.


Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of nodemanagerautostart](#attributes)

### trust_keystore_passphrase<a name='nodemanagerautostart_trust_keystore_passphrase'>

Passphrase to use for the trust keystore.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of nodemanagerautostart](#attributes)

### systemd_script_location<a name='nodemanagerautostart_systemd_script_location'>

Location to put the systemd script.

Type: `Optional[Stdlib::Absolutepath]`

Default:`undef`

[Back to overview of nodemanagerautostart](#attributes)
