---
title: oimconfig
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview


This defined type allows you to configure OIM , oim server, design or remote configuration. Here is an example on how you could use this:

```
ora_install::utils::oimconfig{ 'oimDomain':
  version                 => 1112,
  oim_home                => '/opt/oracle/middleware11g/Oracle_IDM1',
  server_config           => true,
  oim_password            => 'Welcome01',
  remote_config           => false,
  keystore_password       => 'Welcome01',
  design_config           => false,
  oimserver_hostname      => 'oim1admin.example.com',
  oimserver_port          => '14000',
  repository_database_url => "oimdb.example.com:1521:oimrepos.example.com",
  repository_prefix       => "DEV",
  repository_password     => "Welcome01",
}
```




## Attributes



Attribute Name                                                | Short Description                                                                                 |
------------------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[adminserver_address](#oimconfig_adminserver_address)         | The address of the admin server.                                                                  |
[adminserver_name](#oimconfig_adminserver_name)               | The name of the Admin Server.                                                                     |
[adminserver_port](#oimconfig_adminserver_port)               | The IP port the admin server is listening on.                                                     |
[bi_cluster_name](#oimconfig_bi_cluster_name)                 | Cluster where BI is running.                                                                      |
[bi_enabled](#oimconfig_bi_enabled)                           | Boolean to determine if you want BI enabled.                                                      |
[design_config](#oimconfig_design_config)                     | Boolean to determine if you want to config oim design.                                            |
[domain_name](#oimconfig_domain_name)                         | The domain name.                                                                                  |
[download_dir](#oimconfig_download_dir)                       | The directory where the Puppet software puts all downloaded files.                                |
[jdk_home_dir](#oimconfig_jdk_home_dir)                       | The homdirectory for the Java evelopment Kit.                                                     |
[keystore_password](#oimconfig_keystore_password)             | Password to use when opening the keystore.                                                        |
[log_output](#oimconfig_log_output)                           | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#oimconfig_logoutput)                             | log the outputs of Puppet exec or not.                                                            |
[middleware_home_dir](#oimconfig_middleware_home_dir)         | Middleware home directory.                                                                        |
[nodemanager_port](#oimconfig_nodemanager_port)               | The IP port the nodemanager is listening on.                                                      |
[oim_home](#oimconfig_oim_home)                               | Directory to contain the OIM home.                                                                |
[oim_password](#oimconfig_oim_password)                       | OIM password.                                                                                     |
[oimserver_hostname](#oimconfig_oimserver_hostname)           | Hostname for the oimserver.                                                                       |
[oimserver_name](#oimconfig_oimserver_name)                   | Name to use for the OIM server.                                                                   |
[oimserver_port](#oimconfig_oimserver_port)                   | IP port for the OIM server.                                                                       |
[os_group](#oimconfig_os_group)                               | The os group used to install and run WebLogic.                                                    |
[os_user](#oimconfig_os_user)                                 | The os user used to install and run WebLogic.                                                     |
[remote_config](#oimconfig_remote_config)                     |                                                                                                   |
[repository_database_url](#oimconfig_repository_database_url) | The jdbc URL of the RCU repository.                                                               |
[repository_password](#oimconfig_repository_password)         | The password to use for accessing the RCU repository.                                             |
[repository_prefix](#oimconfig_repository_prefix)             | Extra prefix to use for the RCU.                                                                  |
[server_config](#oimconfig_server_config)                     |                                                                                                   |
[soaserver_name](#oimconfig_soaserver_name)                   | Name of the SOA server.                                                                           |
[version](#oimconfig_version)                                 | The version that is installed in the used Oracle home.                                            |
[weblogic_home_dir](#oimconfig_weblogic_home_dir)             | Directory to use as WebLogic home.                                                                |
[weblogic_password](#oimconfig_weblogic_password)             | The password of the base WebLogic user name.                                                      |
[weblogic_user](#oimconfig_weblogic_user)                     | The base WebLogic username to configure.                                                          |
[wls_domains_dir](#oimconfig_wls_domains_dir)                 | The root directory where all domain directories reside in.                                        |




### version<a name='oimconfig_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Wls_install::Versions`

Default:`undef`

[Back to overview of oimconfig](#attributes)

### oim_home<a name='oimconfig_oim_home'>

Directory to contain the OIM home.

Type: `Stdlib::Absolutepath`

Default:`undef`

[Back to overview of oimconfig](#attributes)

### server_config<a name='oimconfig_server_config'>



Type: `Boolean`

Default:`false`

[Back to overview of oimconfig](#attributes)

### oim_password<a name='oimconfig_oim_password'>

OIM password.

Type: `String[1]`

Default:`undef`

[Back to overview of oimconfig](#attributes)

### remote_config<a name='oimconfig_remote_config'>



Type: `Boolean`

Default:`false`

[Back to overview of oimconfig](#attributes)

### keystore_password<a name='oimconfig_keystore_password'>

Password to use when opening the keystore.

Type: `String[1]`

Default:`undef`

[Back to overview of oimconfig](#attributes)

### design_config<a name='oimconfig_design_config'>

Boolean to determine if you want to config oim design.

Type: `Boolean`

Default:`false`

[Back to overview of oimconfig](#attributes)

### oimserver_hostname<a name='oimconfig_oimserver_hostname'>

Hostname for the oimserver.

Type: `String[1]`

Default:`undef`

[Back to overview of oimconfig](#attributes)

### oimserver_port<a name='oimconfig_oimserver_port'>

IP port for the OIM server.

Type: `Integer`

Default:`14000`

[Back to overview of oimconfig](#attributes)

### soaserver_name<a name='oimconfig_soaserver_name'>

Name of the SOA server.

Type: `String[1]`

Default:`'soa_server1'`

[Back to overview of oimconfig](#attributes)

### oimserver_name<a name='oimconfig_oimserver_name'>

Name to use for the OIM server.

Type: `String[1]`

Default:`'oim_server1'`

[Back to overview of oimconfig](#attributes)

### bi_enabled<a name='oimconfig_bi_enabled'>

Boolean to determine if you want BI enabled.

Type: `Boolean`

Default:`false`

[Back to overview of oimconfig](#attributes)

### bi_cluster_name<a name='oimconfig_bi_cluster_name'>

Cluster where BI is running.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of oimconfig](#attributes)

### repository_database_url<a name='oimconfig_repository_database_url'>

The jdbc URL of the RCU repository.

Type: `Optional[String[1]]`

Default:`lookup({name => 'repository_database_url', default_value => undef})`

[Back to overview of oimconfig](#attributes)

### repository_prefix<a name='oimconfig_repository_prefix'>

Extra prefix to use for the RCU.

Type: `String[1]`

Default:`lookup({name => 'repository_prefix', default_value => 'DEV'})`

[Back to overview of oimconfig](#attributes)

### repository_password<a name='oimconfig_repository_password'>

The password to use for accessing the RCU repository.

Type: `String[1]`

Default:`lookup({name => 'repository_password', default_value => 'Welcome01'})`

[Back to overview of oimconfig](#attributes)

### jdk_home_dir<a name='oimconfig_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir'})`

[Back to overview of oimconfig](#attributes)

### weblogic_home_dir<a name='oimconfig_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir'})`

[Back to overview of oimconfig](#attributes)

### middleware_home_dir<a name='oimconfig_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_middleware_home_dir'})`

[Back to overview of oimconfig](#attributes)

### wls_domains_dir<a name='oimconfig_wls_domains_dir'>

The root directory where all domain directories reside in.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_domains_dir', default_value => undef})`

[Back to overview of oimconfig](#attributes)

### domain_name<a name='oimconfig_domain_name'>

The domain name.

Type: `String[1]`

Default:`lookup({name => 'domain_name'})`

[Back to overview of oimconfig](#attributes)

### adminserver_name<a name='oimconfig_adminserver_name'>

The name of the Admin Server.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver', default_value => 'AdminServer'})`

[Back to overview of oimconfig](#attributes)

### adminserver_address<a name='oimconfig_adminserver_address'>

The address of the admin server. May be a DNS name or a physical IP address.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver_address', default_value => 'localhost'})`

[Back to overview of oimconfig](#attributes)

### adminserver_port<a name='oimconfig_adminserver_port'>

The IP port the admin server is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_adminserver_port', default_value => 7001})`

[Back to overview of oimconfig](#attributes)

### nodemanager_port<a name='oimconfig_nodemanager_port'>

The IP port the nodemanager is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_nodemanager_port', default_value => 5556})`

[Back to overview of oimconfig](#attributes)

### weblogic_user<a name='oimconfig_weblogic_user'>

The base WebLogic username to configure.

Type: `String[1]`

Default:`lookup({name => 'wls_weblogic_user', default_value => 'weblogic'})`

[Back to overview of oimconfig](#attributes)

### weblogic_password<a name='oimconfig_weblogic_password'>

The password of the base WebLogic user name.

Type: `String[1]`

Default:`lookup({name => 'domain_wls_password'})`

[Back to overview of oimconfig](#attributes)

### os_user<a name='oimconfig_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of oimconfig](#attributes)

### os_group<a name='oimconfig_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of oimconfig](#attributes)

### download_dir<a name='oimconfig_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of oimconfig](#attributes)

### logoutput<a name='oimconfig_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of oimconfig](#attributes)

### log_output<a name='oimconfig_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum[
        'on_failure'
      ]
    ]
  ]`

Default:`undef`

[Back to overview of oimconfig](#attributes)
