---
title: webtier
keywords: documentation
layout: documentation
sidebar: wls_install_sidebar
toc: false
---
## Overview

This defined type allows you to add an OHS instance to a WebLogic Domain and in the Enterprise Manager, optional with OHS OAM Webgate. Here is an example on how you could use this:

```
ora_install::utils::webtier{ 'ohs1':
  action_name       => 'create',
  instance_name     => 'ohs1',
  webgate_configure => true,
}
```






## Attributes



Attribute Name                                            | Short Description                                                                                 |
--------------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
[action_name](#webtier_action_name)                       | Action to perform.                                                                                |
[adminserver_address](#webtier_adminserver_address)       | The address of the admin server.                                                                  |
[adminserver_port](#webtier_adminserver_port)             | The IP port the admin server is listening on.                                                     |
[domain_configure](#webtier_domain_configure)             |                                                                                                   |
[domain_name](#webtier_domain_name)                       | The domain name.                                                                                  |
[download_dir](#webtier_download_dir)                     | The directory where the Puppet software puts all downloaded files.                                |
[instance_name](#webtier_instance_name)                   |                                                                                                   |
[jdk_home_dir](#webtier_jdk_home_dir)                     | The homdirectory for the Java evelopment Kit.                                                     |
[log_output](#webtier_log_output)                         | **DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release. |
[logoutput](#webtier_logoutput)                           | log the outputs of Puppet exec or not.                                                            |
[machine_name](#webtier_machine_name)                     | Name of the weblogic machine to use.                                                              |
[middleware_home_dir](#webtier_middleware_home_dir)       | Middleware home directory.                                                                        |
[oamadminserverhostname](#webtier_oamadminserverhostname) |                                                                                                   |
[oamadminserverport](#webtier_oamadminserverport)         |                                                                                                   |
[os_group](#webtier_os_group)                             | The os group used to install and run WebLogic.                                                    |
[os_user](#webtier_os_user)                               | The os user used to install and run WebLogic.                                                     |
[version](#webtier_version)                               | The version that is installed in the used Oracle home.                                            |
[webgate_agentname](#webtier_webgate_agentname)           |                                                                                                   |
[webgate_configure](#webtier_webgate_configure)           |                                                                                                   |
[webgate_hostidentifier](#webtier_webgate_hostidentifier) |                                                                                                   |
[weblogic_home_dir](#webtier_weblogic_home_dir)           | Directory to use as WebLogic home.                                                                |
[weblogic_password](#webtier_weblogic_password)           | The password of the base WebLogic user name.                                                      |
[weblogic_user](#webtier_weblogic_user)                   | The base WebLogic username to configure.                                                          |
[wls_domains_dir](#webtier_wls_domains_dir)               | The root directory where all domain directories reside in.                                        |




### version<a name='webtier_version'>

The version that is installed in the used Oracle home.

Puppet uses this value to decide on version specific actions.

Type: `Wls_install::Versions`

Default:`lookup({name => 'wls_version', default_value => 1111})`

[Back to overview of webtier](#attributes)

### weblogic_home_dir<a name='webtier_weblogic_home_dir'>

Directory to use as WebLogic home.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_weblogic_home_dir'})`

[Back to overview of webtier](#attributes)

### middleware_home_dir<a name='webtier_middleware_home_dir'>

Middleware home directory.


Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_middleware_home_dir'})`

[Back to overview of webtier](#attributes)

### jdk_home_dir<a name='webtier_jdk_home_dir'>

The homdirectory for the Java evelopment Kit.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_jdk_home_dir'})`

[Back to overview of webtier](#attributes)

### wls_domains_dir<a name='webtier_wls_domains_dir'>

The root directory where all domain directories reside in.

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_domains_dir', default_value => undef})`

[Back to overview of webtier](#attributes)

### domain_name<a name='webtier_domain_name'>

The domain name.

Type: `String[1]`

Default:`lookup({name => 'domain_name'})`

[Back to overview of webtier](#attributes)

### adminserver_address<a name='webtier_adminserver_address'>

The address of the admin server. May be a DNS name or a physical IP address.

Type: `String[1]`

Default:`lookup({name => 'domain_adminserver_address', default_value => 'localhost'})`

[Back to overview of webtier](#attributes)

### adminserver_port<a name='webtier_adminserver_port'>

The IP port the admin server is listening on.

Type: `Integer`

Default:`lookup({name => 'domain_adminserver_port', default_value => 7001})`

[Back to overview of webtier](#attributes)

### action_name<a name='webtier_action_name'>

Action to perform. Valid values are:

- create
- delete
Type: `Enum['create','delete']`

Default:`'create'`

[Back to overview of webtier](#attributes)

### webgate_configure<a name='webtier_webgate_configure'>


Type: `Boolean`

Default:`false`

[Back to overview of webtier](#attributes)

### webgate_agentname<a name='webtier_webgate_agentname'>


Type: `Optional[String[1]]`

Default:`lookup({name => 'webgate_agentname', default_value => undef})`

[Back to overview of webtier](#attributes)

### webgate_hostidentifier<a name='webtier_webgate_hostidentifier'>


Type: `Optional[String[1]]`

Default:`lookup({name => 'webgate_hostidentifier', default_value => undef})`

[Back to overview of webtier](#attributes)

### oamadminserverhostname<a name='webtier_oamadminserverhostname'>


Type: `String[1]`

Default:`lookup({name => 'oamadminserverhostname', default_value => 'localhost'})`

[Back to overview of webtier](#attributes)

### oamadminserverport<a name='webtier_oamadminserverport'>


Type: `Integer`

Default:`lookup({name => 'oamadminserverport', default_value => 7001})`

[Back to overview of webtier](#attributes)

### domain_configure<a name='webtier_domain_configure'>


Type: `Boolean`

Default:`true`

[Back to overview of webtier](#attributes)

### instance_name<a name='webtier_instance_name'>


Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of webtier](#attributes)

### machine_name<a name='webtier_machine_name'>

Name of the weblogic machine to use.

Type: `Optional[String[1]]`

Default:`undef`

[Back to overview of webtier](#attributes)

### weblogic_user<a name='webtier_weblogic_user'>

The base WebLogic username to configure.

Type: `String[1]`

Default:`lookup({name => 'wls_weblogic_user', default_value => 'weblogic'})`

[Back to overview of webtier](#attributes)

### weblogic_password<a name='webtier_weblogic_password'>

The password of the base WebLogic user name.

Type: `String[1]`

Default:`lookup({name => 'domain_wls_password'})`

[Back to overview of webtier](#attributes)

### os_user<a name='webtier_os_user'>

The os user used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_user'})`

[Back to overview of webtier](#attributes)

### os_group<a name='webtier_os_group'>

The os group used to install and run WebLogic.


Type: `String[1]`

Default:`lookup({name => 'wls_os_group'})`

[Back to overview of webtier](#attributes)

### download_dir<a name='webtier_download_dir'>

The directory where the Puppet software puts all downloaded files.

Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.

The default value is: `/install`

Type: `Stdlib::Absolutepath`

Default:`lookup({name => 'wls_download_dir'})`

[Back to overview of webtier](#attributes)

### logoutput<a name='webtier_logoutput'>

log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]`

Default:`lookup({name => 'logoutput', default_value => 'on_failure'})`

[Back to overview of webtier](#attributes)

### log_output<a name='webtier_log_output'>

**DEPRECATED** This parameter is replaced by 'logoutput' and will be removed in a future release.
log the outputs of Puppet exec or not.

When you specify `true` Puppet will log all output of `exec` types.

Valid values are:

- `true`
- `false`
- `on_failure`

Type: `Optional[
    Variant[
      Boolean,
      Enum['on_failure']
    ]
  ]`

Default:`undef`

[Back to overview of webtier](#attributes)
